aamras
======

![build](https://github.com/allekmott/aamras/workflows/build/badge.svg)

**aam ras** or *आम रस* - Hindi for mango juice 🥭.

It is pronounced "*arm Russ*" if the *r* in *arm* is silent.

aamras provides a high-level interface for headless browser manipulation. It is currently built on [selenium](https://github.com/SeleniumHQ/selenium).
